@@ -126,6 +126,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
   { "audio/mpeg", "mp3", NULL },
   { "application/x-nsv-vp3-mp3", "nsv", "video/x-nsv" },
   { "video/flv", "flv", "application/x-flash-video" },
+  { "video/webm", "webm", NULL },
   { "application/x-totem-plugin", "", "Totem Multimedia plugin" },
   { "audio/midi", "mid, midi", NULL },
 #else
@@ -276,6 +277,25 @@ totemPlugin::Command (const char *aCommand)
 				    G_TYPE_INVALID);
 }
 
+void
+totemPlugin::SetTime (guint64 aTime)
+{
+	D ("SetTime '%lu'", aTime);
+
+	/* FIXME: queue the action instead */
+	if (!mViewerReady)
+		return;
+
+	mTime = aTime;
+
+	assert (mViewerProxy);
+	dbus_g_proxy_call_no_reply (mViewerProxy,
+				    "SetTime",
+				    G_TYPE_UINT64, GetTime(),
+				    G_TYPE_INVALID,
+				    G_TYPE_INVALID);
+}
+
 void
 totemPlugin::SetVolume (double aVolume)
 {
@@ -1023,7 +1043,6 @@ totemPlugin::RequestStream (bool aForceViewer)
 	/* Prefer filename over src */
 	if (mURLURI) {
 		requestURI = mURLURI;
-		baseURI = mSrcURI; /* FIXME: that correct? */
 	}
 #endif /* TOTEM_GMP_PLUGIN */
 
@@ -1039,11 +1058,14 @@ totemPlugin::RequestStream (bool aForceViewer)
 		requestURL = href;
 	}
 #endif
+
+       /* We should be following QTSRCDONTUSEBROWSER instead */
+	aForceViewer = true;
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
 
-#ifdef TOTEM_MULLY_PLUGIN
+#if defined (TOTEM_MULLY_PLUGIN) || defined (TOTEM_CONE_PLUGIN)
 	aForceViewer = true;
-#endif /* TOTEM_MULLY_PLUGIN */
+#endif /* TOTEM_MULLY_PLUGIN || TOTEM_CONE_PLUGIN */
 
 	/* Fallback */
 	if (!requestURI)
@@ -1064,7 +1086,7 @@ totemPlugin::RequestStream (bool aForceViewer)
         mRequestBaseURI = g_strdup (baseURI);
 
 	/* If the URL is supported and the caller isn't asking us to make
-	 * the viewer open the stream, we call OpenStream, and
+	 * the viewer open the stream, we call SetupStream, and
 	 * otherwise OpenURI. */
 	if (!aForceViewer && IsSchemeSupported (requestURI, baseURI)) {
 		/* This will fail for the 2nd stream, but we shouldn't
@@ -1072,8 +1094,8 @@ totemPlugin::RequestStream (bool aForceViewer)
 
 		mViewerPendingCall =
 			dbus_g_proxy_begin_call (mViewerProxy,
-						 "OpenStream",
-						 ViewerOpenStreamCallback,
+						 "SetupStream",
+						 ViewerSetupStreamCallback,
 						 reinterpret_cast<void*>(this),
 						 NULL,
 						 G_TYPE_STRING, requestURI,
@@ -1255,9 +1277,12 @@ totemPlugin::TickCallback (DBusGProxy *proxy,
 			scriptable->mPluginState = totemNarrowSpacePlayer::eState_Playable;
 			break;
 		case TOTEM_STATE_STOPPED:
-			if (scriptable->mPluginState == totemNarrowSpacePlayer::eState_Playable)
+			if (scriptable->mPluginState == totemNarrowSpacePlayer::eState_Playable) {
 				scriptable->mPluginState = totemNarrowSpacePlayer::eState_Complete;
-			else
+				/* The QuickTime plugin expects the duration to be the
+				 * length of the file on EOS */
+				plugin->mTime = plugin->mDuration;
+			} else
 				scriptable->mPluginState = totemNarrowSpacePlayer::eState_Waiting;
 			break;
 		default:
@@ -1341,6 +1366,29 @@ totemPlugin::ViewerOpenStreamCallback (DBusGProxy *aProxy,
 	    plugin->mAutoPlay) {
 		plugin->Command (TOTEM_COMMAND_PLAY);
 	}
+}
+
+/* static */ void
+totemPlugin::ViewerSetupStreamCallback (DBusGProxy *aProxy,
+					DBusGProxyCall *aCall,
+					void *aData)
+{
+	totemPlugin *plugin = reinterpret_cast<totemPlugin*>(aData);
+
+	g_debug ("SetupStream reply");
+
+// 	assert (aCall == plugin->mViewerPendingCall, "OpenStream not the current call");
+        if (aCall != plugin->mViewerPendingCall)
+          return;
+
+	plugin->mViewerPendingCall = NULL;
+
+	GError *error = NULL;
+	if (!dbus_g_proxy_end_call (aProxy, aCall, &error, G_TYPE_INVALID)) {
+		g_warning ("SetupStream failed: %s", error->message);
+		g_error_free (error);
+		return;
+	}
 
 	assert (!plugin->mExpectingStream); /* Already expecting a stream */
 
@@ -1610,7 +1658,23 @@ totemPlugin::SetURL (const char* aURL)
 
         mURLURI = g_strdup (aURL);
 
-	/* FIXME: what is the correct base for the URL param? mSrcURI or mBaseURI? */
+	/* FIXME: security checks? */
+        /* FIXMEchpe: resolve the URI here? */
+}
+
+void
+totemPlugin::SetBaseURL (const char *aBaseURL)
+{
+        g_free (mBaseURI);
+
+	/* Don't allow empty URL */
+        if (!aBaseURL || !aBaseURL[0]) {
+                mBaseURI = NULL;
+		return;
+        }
+
+        mBaseURI = g_strdup (aBaseURL);
+
 	/* FIXME: security checks? */
         /* FIXMEchpe: resolve the URI here? */
 }
@@ -1961,6 +2025,12 @@ totemPlugin::Init (NPMIMEType mimetype,
         if (filename) {
                 SetURL (filename);
         }
+
+        /* http://msdn.microsoft.com/en-us/library/dd564090(v=VS.85).aspx */
+        const char *base = (const char *) g_hash_table_lookup (args, "baseurl");
+        if (base)
+		SetBaseURL (base);
+
 #endif /* TOTEM_GMP_PLUGIN */
 
 #ifdef TOTEM_NARROWSPACE_PLUGIN
@@ -2032,11 +2102,21 @@ totemPlugin::Init (NPMIMEType mimetype,
 
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
 
-/* VLC plugin defaults to have its controller hidden
- * But we don't want to hide it if VLC wasn't explicitely
- * requested */
 #ifdef TOTEM_CONE_PLUGIN
-	if (strstr ((const char *) mimetype, "vlc") != NULL)
+	/* VLC plugin defaults to have its controller hidden.
+	 * But we don't want to hide it if VLC wasn't explicitely requested.
+	 * VLC plugin checks for toolbar argument in vlcplugin.cpp: VlcPlugin::init()
+	 * If the argument is missing or not set to "true" the toolbar is hidden.
+	 * We use a different approach:
+	 * - If there is no toolbar argument or it is not set to "false"
+	 *   the  controller is visible (otherwise it is hidden)
+	 * - If VLC is requested explicitely (via mimetype) and
+	 *   the toolbar argument is not set to "true",
+	 *   the controller is hidden (otherwise it is visible)
+	 */
+	if (!GetBooleanValue (args, "toolbar", true) ||
+	    (!GetBooleanValue (args, "toolbar", false) &&
+	     strstr ((const char *) mimetype, "vlc") != NULL))
 		mControllerHidden = true;
 #endif
 
@@ -2096,6 +2176,7 @@ totemPlugin::Init (NPMIMEType mimetype,
 
 	/* Dump some disagnostics */
 	D ("mSrcURI: %s", mSrcURI ? mSrcURI : "");
+	D ("mBaseURI: %s", mBaseURI ? mBaseURI : "");
 	D ("mCache: %d", mCache);
 	D ("mControllerHidden: %d", mControllerHidden);
 	D ("mShowStatusbar: %d", mShowStatusbar);
@@ -2235,6 +2316,16 @@ totemPlugin::NewStream (NPMIMEType type,
 	mBytesStreamed = 0;
 	mBytesLength = stream->end;
 
+	gint64 length = mBytesLength;
+	mViewerPendingCall =
+		dbus_g_proxy_begin_call (mViewerProxy,
+					 "OpenStream",
+					 ViewerOpenStreamCallback,
+					 reinterpret_cast<void*>(this),
+					 NULL,
+					 G_TYPE_INT64, length,
+					 G_TYPE_INVALID);
+
 	return NPERR_NO_ERROR;
 }
 
