@@ -314,7 +314,14 @@ totem_cmml_parse_npt (const gchar *str)
 		return -1;
 	if (G_UNLIKELY (m > 59 || m < 0))
 		return -1;
-	if (G_UNLIKELY (s >= 60.0 || s < 0.0))
+
+	/* We break slightly with the specifications here and allow seconds-only values greater than 60 seconds.
+	 * (i.e. we allow "90" to be successfully parsed as 1.5 minutes and returned as 90 seconds, rather than
+	 * returning an error because it's > 60). This is because Totem previously (incorrectly) wrote out timestamps
+	 * in this (seconds only, potentially > 60) format; so for compatibility with CMML files written by older
+	 * versions of Totem, we have to allow such formats.
+	 * However, if either h or m is non-zero, we error out as before. */
+	if (G_UNLIKELY ((h != 0 || m != 0) && (s >= 60.0 || s < 0.0)))
 		return -1;
 
 	return (h * 3600.0) + (m * 60.0) + s;
@@ -488,11 +495,13 @@ totem_cmml_read_clip_cb (TotemCmmlClip	*clip,
 
 	new_clip = totem_cmml_clip_copy (clip);
 
-	if (G_LIKELY (new_clip != NULL && new_clip->time_start >= 0))
+	if (G_LIKELY (new_clip != NULL && new_clip->time_start >= 0)) {
 		* ( (GList **) user_data) = g_list_append ( * ( (GList **) user_data), new_clip);
 	/* clip with -1 start time is bad one, remove it */
-	else
+	} else if (new_clip != NULL) {
+		g_warning ("Ignoring clip '%s' due to having an invalid start time: %" G_GINT64_FORMAT, new_clip->title, new_clip->time_start);
 		totem_cmml_clip_free (new_clip);
+	}
 }
 
 /**
@@ -805,6 +814,9 @@ totem_cmml_write_file_async (TotemCmmlAsyncData *data)
 		guint8		*stream;
 		TotemCmmlClip	*clip;
 		gchar		start_buf[G_ASCII_DTOSTR_BUF_SIZE];
+		gchar		*start_string;
+		gint		hours, minutes;
+		gdouble		seconds;
 
 		clip = (TotemCmmlClip *) cur_clip->data;
 		time_start = ((gdouble) clip->time_start) / 1000;
@@ -818,8 +830,13 @@ totem_cmml_write_file_async (TotemCmmlAsyncData *data)
 		if (G_UNLIKELY (res < 0))
 			break;
 
-		res = xmlTextWriterWriteAttribute (writer, (const xmlChar *) "start",
-		                                   (const xmlChar *) g_ascii_dtostr (start_buf, sizeof (buf), time_start));
+		/* Format the time in NPT format (npt:%d:%d:%f) */
+		hours = ((glong) time_start) / 3600;
+		minutes = ((glong) time_start % 3600) / 60;
+		seconds = time_start - ((glong) hours * 3600) - ((glong) minutes * 60);
+		start_string = g_strdup_printf ("npt:%d:%d:%s", hours, minutes, g_ascii_dtostr (start_buf, sizeof (buf), seconds));
+		res = xmlTextWriterWriteAttribute (writer, (const xmlChar *) "start", (const xmlChar *) start_string);
+		g_free (start_string);
 		if (G_UNLIKELY (res < 0))
 			break;
 
