@@ -1,4 +1,5 @@
 #!/usr/bin/python
+# -*- coding: utf-8 -*-
 
 # Python libs
 import re, os
@@ -7,8 +8,7 @@ import urllib2
 #from pprint import pformat
 from socket import timeout as SocketTimeoutError
 #from time import time
-
-import totem
+import gettext
 
 # external libs
 import httplib2
@@ -16,6 +16,11 @@ import feedparser
 import listparser
 from BeautifulSoup import BeautifulStoneSoup
 
+gettext.textdomain("totem")
+
+D_ = gettext.dgettext
+_ = gettext.gettext
+
 IMG_DIR = os.path.join(os.getcwd(), 'resources', 'media')
 
 #try:
@@ -291,8 +296,8 @@ class NoItemsError(Exception):
         self.reason = reason
 
     def __str__(self):
-        reason = self.reason or '<no reason given>'
-        return _('Programme unavailable ("%s")') % (reason)
+        reason = self.reason or _(u'<no reason given>')
+        return _(u'Programme unavailable ("%s")') % (reason)
 
 class memoize(object):
     def __init__(self, func):
@@ -499,7 +504,7 @@ class item(object):
         url = self.mediaselector_url
         #logging.info("Stream XML URL: %s", str(url))
         _, xml = http.request(url)
-        soup = BeautifulStoneSoup(xml)
+        soup = BeautifulStoneSoup(xml, convertEntities = BeautifulStoneSoup.XML_ENTITIES)
         medias = [media(self, m) for m in soup('media')]
         #logging.info('Found media: %s', pformat(medias, indent=8))
         self.medias = medias
@@ -558,15 +563,15 @@ class programme(object):
         #xml.replace('<summary/>', '<summary></summary>')
         #xml = fix_selfclosing(xml)
 
-        soup = BeautifulStoneSoup(xml, selfClosingTags=self_closing_tags)
+        soup = BeautifulStoneSoup(xml, selfClosingTags=self_closing_tags, convertEntities = BeautifulStoneSoup.XML_ENTITIES)
 
         self.meta = {}
         self._items = []
         self._related = []
 
         #logging.info('  Found programme: %s', soup.playlist.title.string)
-        self.meta['title'] = soup.playlist.title.string
-        self.meta['summary'] = soup.playlist.summary.string
+        self.meta['title'] = soup.playlist.title.string.encode ('utf-8')
+        self.meta['summary'] = soup.playlist.summary.string.encode ('utf-8')
         self.meta['updated'] = soup.playlist.updated.string
 
         if soup.playlist.noitems:
