@@ -23,7 +23,6 @@
 #ifndef TOTEM_OPTIONS_H
 #define TOTEM_OPTIONS_H
 
-#include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 
 #include "totem.h"
@@ -48,7 +47,6 @@ typedef struct {
 	gboolean quit;
 	gboolean enqueue;
 	gboolean replace;
-	gboolean notconnectexistingsession;
 	gdouble playlistidx;
 	gint64 seek;
 	gchar **filenames;
@@ -62,7 +60,7 @@ void totem_options_process_early (Totem *totem,
 				  const TotemCmdLineOptions* options);
 void totem_options_process_late (Totem *totem, 
 				 const TotemCmdLineOptions* options);
-void totem_options_process_for_server (GApplication *app,
+void totem_options_process_for_server (Totem *totem,
 				       const TotemCmdLineOptions* options);
 
 G_END_DECLS
