@@ -87,12 +87,34 @@ GtkWidget *totem_playlist_new      (void);
  * @display_name is if you have a preferred display string for the mrl,
  * NULL otherwise
  */
-gboolean totem_playlist_add_mrl  (TotemPlaylist *playlist,
-				  const char *mrl,
-				  const char *display_name);
-gboolean totem_playlist_add_mrl_with_cursor (TotemPlaylist *playlist,
-					     const char *mrl,
-					     const char *display_name);
+void totem_playlist_add_mrl (TotemPlaylist *playlist,
+                             const char *mrl,
+                             const char *display_name,
+                             gboolean cursor,
+                             GCancellable *cancellable,
+                             GAsyncReadyCallback callback,
+                             gpointer user_data);
+gboolean totem_playlist_add_mrl_finish (TotemPlaylist *playlist,
+                                        GAsyncResult *result);
+gboolean totem_playlist_add_mrl_sync (TotemPlaylist *playlist,
+                                      const char *mrl,
+                                      const char *display_name);
+
+typedef struct TotemPlaylistMrlData TotemPlaylistMrlData;
+
+TotemPlaylistMrlData *totem_playlist_mrl_data_new (const gchar *mrl,
+                                                   const gchar *display_name);
+void totem_playlist_mrl_data_free (TotemPlaylistMrlData *data);
+
+void totem_playlist_add_mrls (TotemPlaylist *self,
+                              GList *mrls,
+                              gboolean cursor,
+                              GCancellable *cancellable,
+                              GAsyncReadyCallback callback,
+                              gpointer user_data);
+gboolean totem_playlist_add_mrls_finish (TotemPlaylist *self,
+                                         GAsyncResult *result,
+                                         GError **error);
 
 void totem_playlist_save_current_playlist (TotemPlaylist *playlist,
 					   const char *output);
@@ -109,13 +131,12 @@ void       totem_playlist_clear_with_g_mount (TotemPlaylist *playlist,
 char      *totem_playlist_get_current_mrl (TotemPlaylist *playlist,
 					   char **subtitle);
 char      *totem_playlist_get_current_title (TotemPlaylist *playlist,
-					     gboolean *custom);
+					     char         **content_type);
 char      *totem_playlist_get_title (TotemPlaylist *playlist,
 				     guint title_index);
 
 gboolean   totem_playlist_set_title (TotemPlaylist *playlist,
-				     const char *title,
-				     gboolean force);
+				     const char *title);
 void       totem_playlist_set_current_subtitle (TotemPlaylist *playlist,
 						const char *subtitle_uri);
 
