@@ -607,7 +607,10 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 	/* Take the screenshots and composite them into a pixbuf */
 	current_column = current_row = x = y = 0;
 	for (pos = screenshot_interval; pos <= stream_length; pos += screenshot_interval) {
-		screenshot = capture_frame_at_time (bvw, input, output, pos);
+		if (pos == stream_length)
+			screenshot = capture_frame_at_time (bvw, input, output, pos - 1);
+		else
+			screenshot = capture_frame_at_time (bvw, input, output, pos);
 
 		if (pixbuf == NULL) {
 			screenshot_width = gdk_pixbuf_get_width (screenshot);
